base_mult_montgomery

Function base_mult_montgomery 

pub fn base_mult_montgomery(a: &Polynomial, b: &Polynomial) -> Polynomial
Multiplication of two polynomials in NTT domain

Borrowed from: https://github.com/pq-crystals/kyber/blob/main/ref/poly.c#L290 Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.