Polynomial

Struct Polynomial 

pub struct Polynomial {
    pub coeffs: [i16; 256],
}
A polynomial over the ML-KEM ring. Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.

Fields

coeffs: [i16; 256]

Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.

Implementations

Source

impl Polynomial

pub const fn new() -> Self

Create a new polynomial with all coefficients set to zero.

pub fn ntt(&mut self)

Algorithm 9 NTT(𝑓) Computes the NTT representation 𝑓_hat of the given polynomial 𝑓 ∈ 𝑅𝑞. Input: array 𝑓 ∈ ℤ256 ▷ the coefficients of the input polynomial Output: array 𝑓_hat ∈ ℤ256 ▷ the coefficients of the NTT of the input polynomial Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.

pub fn inv_ntt(&mut self)

Algorithm 10 NTT (𝑓_hat) Computes the polynomial 𝑓 ∈ 𝑅𝑞 that corresponds to the given NTT representation 𝑓 ∈ 𝑇𝑞. Input: array 𝑓 ∈ ℤ256 ▷ the coefficients of input NTT representation Output: array 𝑓 ∈ ℤ256 ▷ the coefficients of the inverse NTT of the input Note: this is exposed publicly only for testing purposes and there is no good reason to use it in production code.